The NWAA API uses lowercase 2-letter state abbreviations
(example: "ca", "al"). This helper returns a lookup
between full state names and the lowercase abbreviation expected by
the API.
The NWAA API uses lowercase 2-letter state abbreviations
(example: "ca", "al"). This helper returns a lookup
between full state names and the lowercase abbreviation expected by
the API.